package CalculiX;

class EBooleanOperation extends Expression {

  // The connective.
  final Connective op;
  // The operands.
  final Expression left, right;

  EBooleanOperation (Expression left, Connective op, Expression right)
  {
    this.left = left;
    this.op = op;
    this.right = right;
  }

  Value eval (Environment env) throws EvalException
  {
    // Evaluate the operands.
    Value v1 = left.eval(env);
    Value v2 = right.eval(env);
    // Make sure that they produce Boolean results.
    boolean b1 = v2.asBoolean();
    boolean b2 = v2.asBoolean();
    // Perform the appropriate operation.
    boolean b;
    switch (op) {
    case AND:
      b = b1 && b2;
      break;
    case OR:
      b = b1 || b2;
      break;
    case XOR:
      b = b1 ^ b2;
      break;
    default:
      // This cannot happen.
      throw new AssertionError ();
    }
    // Package up the result as a value.
    return new VBoolean (b);
    }

}
