package CalculiX;

class EIntegerComparison extends Expression {

  // The comparator.
  final Comparator op;
  // The operands.
  final Expression left, right;

  EIntegerComparison (Expression left, Comparator op, Expression right)
  {
    this.left = left;
    this.op = op;
    this.right = right;
  }

  Value eval (Environment env) throws EvalException
  {
    // Evaluate the operands.
    Value v1 = left.eval(env);
    Value v2 = right.eval(env);
    // Make sure that they produce integer results.
    int i1 = v1.asInteger();
    int i2 = v2.asInteger();
    // Perform the appropriate operation.
    boolean b;
    switch (op) {
    case LESSTHAN:
      b = i1 < i2;
      break;
    case LESSTHANOREQUALTO:
      b = i1 <= i2;
      break;
    case EQUALS:
	b = (i1 == i2);
      break;
    default:
      // This cannot happen.
      throw new AssertionError ();
    }
    // Package up the result as a value.
    return new VBoolean (b);
    }

}
