package CalculiX;

class EIntegerOperation extends Expression {

  // The operator.
  final Operator op;
  // The operands.
  final Expression left, right;

  EIntegerOperation (Expression left, Operator op, Expression right)
  {
    this.left = left;
    this.op = op;
    this.right = right;
  }

  Value eval (Environment env) throws EvalException
  {
    // Evaluate the operands.
    Value v1 = left.eval(env);
    Value v2 = right.eval(env);
    // Make sure that they produce integer results.
    int i1 = v1.asInteger();
    int i2 = v2.asInteger();
    // Perform the appropriate operation.
    int i;
    switch (op) {
    case ADDITION:
      i = i1 + i2;
      break;
    case SUBTRACTION:
      i = i1 - i2;
      break;
    case MULTIPLICATION:
      i = i1 * i2;
      break;
    case DIVISION:
      i = i1 / i2;
      break;
    default:
      // This cannot happen.
      throw new AssertionError ();
    }
    // Package up the result as a value.
    return new VInteger (i);
    }

}
