package CalculiX;

// This class implements an expression of the form
// Sigma_{x=lo}^{hi} {body}.

class ESigma extends Expression {

  // The variable that is used as an index.
  final String x;
  // The low and high bounds.
  final Expression lo, hi;
  // The body.
  final Expression body;

  ESigma (String x, Expression lo, Expression hi, Expression body)
  {
    this.x = x;
    this.lo = lo;
    this.hi = hi;
    this.body = body;
  }

  Value eval (Environment env) throws EvalException
  {
    int lo_value = lo.eval(env).asInteger();
    int hi_value = hi.eval(env).asInteger();
    int sum = 0;
    for (int v = lo_value; v <= hi_value; v++)
      sum += body.eval(
               env.extend(x, new VInteger (v))
             ).asInteger();
    return new VInteger (sum);
  }

}

