package CalculiX;

// This is the interface provided by the scanner.

// Each input symbol has a tag and a semantic value. A tag is represented as
// an integer value. A list of all tags appears in the class "sym". A semantic
// value has type Object. Its actual type depends on the tag.

// The methods that consult or consume the next input symbol can fail and
// throw unknown exceptions (most likely due to input/output errors).

// By convention, the end-of-file is represented by a special input symbol,
// known as EOF, so there always is a next input symbol. In principle,
// consumeNextToken should not be called when the next input symbol is EOF.

interface MyScanner {

  // This method returns the tag of the next input symbol, which is
  // not consumed.

  int consultNextToken () throws Exception;

  // This method returns the semantic value of the next input symbol,
  // which is consumed.

  Object consumeNextToken () throws Exception;

  // This method returns the semantic value of the next input symbol, which is
  // consumed. In addition, it checks that this symbol carries the expected
  // tag; if that is not the case, a syntax error is reported.

  Object consumeNextToken (int expectedTag) throws Exception;

  // This method is used to report a syntax error. It constructs an Exception
  // object, which can then be thrown by the caller.

  Exception syntaxError (String message);

}
